Opens the bundled R Markdown demo (rharv-demo.Rmd), which exercises every
function, plot and dataset of the package, in your editor (RStudio when run
from an RStudio session). Use Knit to render it to HTML.
Opens the bundled R Markdown demo (rharv-demo.Rmd), which exercises every
function, plot and dataset of the package, in your editor (RStudio when run
from an RStudio session). Use Knit to render it to HTML.